==> Undine-1.0.tbz: Undine-1.0/src/packages/rw.c <==
/* This program is a part of RW mudlib
 * See /doc/help/copyright for more info
 -----------------------------------------
 * File   : rw.c
 * Author : Clode@RevivalWorld
 * Date   : 2007-05-26
 * Note   : database package
 * Update :
 *  o 2000-00-00  

 -----------------------------------------
 */


#ifdef LATTICE
#include "/lpc_incl.h"
#include "/comm.h"

#else
#include "../lpc_incl.h"
#include "../comm.h"
#endif

/* N즳 find_player() */
#ifdef NO_ADD_ACTION
#ifdef F_FIND_PLAYER
void
f_find_player PROT((void)) {
	
	int len;
	object_t *ob;
	char *name, path[26] = "/data/user/ /";
	
	name = sp->u.string;
	len = strlen(name)+13;
	
	if( len > 25 )
	{
        	*sp = const0;
        	return;
	}
	
	path[11] = name[0];
	
	len=13;
	while(*name) path[len++] = *name++;

	path[len] = '\0';
	 
	ob = find_object2(path);

	free_string_svalue(sp);
	
    	if (ob && object_visible(ob))
		put_unrefed_undested_object(ob, "find_player");
    	else
		*sp = const0;
}
#endif		
#endif

/*
	Added by Clode@RW 2001/10/8 05:37U
	ΨӤ@Ӥʪinput_toA
*/

#ifdef F_REMOVE_INPUT_TO
void
f_remove_input_to PROT((void))
{
    object_t *ob;

    if (st_num_arg) {
	ob = sp->u.ob;
	pop_stack();
    }
    else ob = current_object;
    
    if( ob->interactive != 0 )
    {
    	ob->interactive->carryover = NULL;
    	ob->interactive->num_carry = 0;
    	ob->interactive->input_to = 0;
    }
}
#endif

/* 
	Written by Clode@Revival World 2002/3/15 07:29U
	N simul_efun base_name 令u efun
*/
#ifdef F_BASE_NAME
void
f_base_name PROT((void)) {
	
	char *res, *tmp;
	
	res = (char *) add_slash(sp->u.ob->name);
	
	free_object(sp->u.ob, "f_base_name");
	
	if( (tmp = strrchr(res, '#')) != 0 )
	{
		*tmp = '\0';
		
		tmp = new_string(strlen(res), "f_base_name");
		
		strcpy(tmp, res);
		
		FREE_MSTR(res);
		put_malloced_string(tmp);
	}
	else
		put_malloced_string(res);
}
#endif

#ifdef F_MCCPP
void 
f_mccpp PROT((void))
{
	int res;

	res = 0;

#ifdef MCCP_SUPPORT
	if (sp->u.ob->interactive)
		res = (sp->u.ob->interactive->compress_stream != NULL);
#endif

	free_object(sp->u.ob, "f_mccpp");
	put_number(res);
}
#endif

==> Undine-1.2.tbz: Undine-1.2/src/packages/rw.c <==
/* This program is a part of RW mudlib
 * See /doc/help/copyright for more info
 -----------------------------------------
 * File   : rw.c
 * Author : Clode@RevivalWorld
 * Date   : 2007-05-26
 * Note   : database package
 * Update :
 *  o 2000-00-00  

 -----------------------------------------
 */


#ifdef LATTICE
#include "/lpc_incl.h"
#include "/comm.h"
#include "/call_out.h"
#else
#include "../lpc_incl.h"
#include "../comm.h"
#include "../call_out.h"
#endif

/* N즳 find_player() */
#ifdef NO_ADD_ACTION
void f_find_player () {
	
	int len;
	object_t *ob;
	char *name, path[26] = "/data/user/ /";
	
	name = (char *)sp->u.string;
	len = strlen(name)+13;
	
	if( len > 25 )
	{
        	*sp = const0;
        	return;
	}
	
	path[11] = name[0];
	
	len=13;
	while(*name) path[len++] = *name++;

	path[len] = '\0';
	 
	ob = find_object2(path);

	free_string_svalue(sp);
	
    	if (ob && object_visible(ob))
		put_unrefed_undested_object(ob, "find_player");
    	else
		*sp = const0;
}
#endif

/*
  Added by Clode@RW 2001/10/8 05:37U
  ΨӤ@Ӥʪ input_to A
*/
#ifdef F_REMOVE_INPUT_TO
void f_remove_input_to ()
{
    object_t *ob;

    if (st_num_arg) {
	ob = sp->u.ob;
	pop_stack();
    }
    else ob = current_object;
    
    if( ob->interactive != 0 )
    {
    	ob->interactive->carryover = NULL;
    	ob->interactive->num_carry = 0;
    	ob->interactive->input_to = 0;
    }
}
#endif

/*
  Τ@]wt HEARTBEAT_INTERVAL 
*/

#ifdef F_SET_HEARTBEAT_INTERVAL
void f_set_heartbeat_interval()
{
	heartbeat_interval = sp->u.number;
	
	pop_stack();
}
#endif

#ifdef F_BUFTOSTR
void f_buftostr()
{
    char *ret = new_string(sp->u.buf->size, "f_to_string");
   
    ret[sp->u.buf->size] = '\0';
    memcpy(ret, sp->u.buf->item, sp->u.buf->size);
   
    free_buffer(sp->u.buf);
    put_malloced_string(ret);
}
#endif

#ifdef F_STRTOBUF
void f_strtobuf()
{
    int len = SVALUE_STRLEN(sp);
    buffer_t *buf = allocate_buffer(len);

    memcpy(buf->item, sp->u.string, len);
    
    pop_stack();
    push_refed_buffer(buf);
}
#endif
